@@ -43,8 +43,6 @@
 #include <glib/gstdio.h>
 #include <glib/gi18n-lib.h>
 
-#include "brasero-session.h"
-#include "brasero-track.h"
 
 #include "burn-basics.h"
 #include "burn-debug.h"
@@ -55,11 +53,26 @@
 #include "brasero-drive.h"
 #include "brasero-medium-monitor.h"
 
+#include "brasero-tags.h"
+#include "brasero-session.h"
+#include "brasero-track.h"
 #include "brasero-track-disc.h"
 
+
 G_DEFINE_TYPE (BraseroBurnSession, brasero_burn_session, G_TYPE_OBJECT);
 #define BRASERO_BURN_SESSION_PRIVATE(o)  (G_TYPE_INSTANCE_GET_PRIVATE ((o), BRASERO_TYPE_BURN_SESSION, BraseroBurnSessionPrivate))
 
+/**
+ * SECTION:brasero-session
+ * @short_description: Store parameters when burning and blanking
+ * @see_also: #BraseroBurn, #BraseroSessionCfg
+ * @include: brasero-session.h
+ *
+ * This object stores all parameters for all operations performed by #BraseroBurn such as
+ * burning, blanking and checksuming. To have this object configured automatically see
+ * #BraseroSessionCfg.
+ **/
+
 struct _BraseroSessionSetting {
 	BraseroDrive *burner;
 
@@ -108,6 +121,7 @@ typedef struct _BraseroBurnSessionPrivate BraseroBurnSessionPrivate;
 #define BRASERO_STR_EQUAL(a, b)	((!(a) && !(b)) || ((a) && (b) && !strcmp ((a), (b))))
 
 typedef enum {
+	TAG_CHANGED_SIGNAL,
 	FLAGS_CHANGED_SIGNAL,
 	TRACK_ADDED_SIGNAL,
 	TRACK_REMOVED_SIGNAL,
@@ -751,6 +765,9 @@ brasero_burn_session_get_rate (BraseroBurnSession *self)
 		return 0;
 
 	medium = brasero_drive_get_medium (priv->settings->burner);
+	if (!medium)
+		return 0;
+
 	max_rate = brasero_medium_get_max_write_speed (medium);
 	if (priv->settings->rate <= 0)
 		return max_rate;
@@ -978,6 +995,46 @@ brasero_burn_session_set_output_image_real (BraseroBurnSession *self,
 	return BRASERO_BURN_OK;
 }
 
+/**
+ * brasero_burn_session_set_image_output_format:
+ * @session: a #BraseroBurnSession
+ * @format: a #BraseroImageFormat
+ *
+ * When the contents of @session should be written to a
+ * file, this function sets format of the image that will be
+ * created.
+ *
+ * NOTE: after a call to this function the #BraseroDrive for
+ * @session will be the fake #BraseroDrive.
+ *
+ * Return value: a #BraseroBurnResult. BRASERO_BURN_OK if it was successfully set;
+ * BRASERO_BURN_ERR otherwise.
+ **/
+
+BraseroBurnResult
+brasero_burn_session_set_image_output_format (BraseroBurnSession *self,
+					    BraseroImageFormat format)
+{
+	BraseroBurnSessionClass *klass;
+	BraseroBurnSessionPrivate *priv;
+	BraseroBurnResult res;
+	gchar *image;
+	gchar *toc;
+
+	g_return_val_if_fail (BRASERO_IS_BURN_SESSION (self), BRASERO_BURN_ERR);
+
+	priv = BRASERO_BURN_SESSION_PRIVATE (self);
+	klass = BRASERO_BURN_SESSION_GET_CLASS (self);
+
+	image = g_strdup (priv->settings->image);
+	toc = g_strdup (priv->settings->toc);
+	res = klass->set_output_image (self, format, image, toc);
+	g_free (image);
+	g_free (toc);
+
+	return res;
+}
+
 /**
  * brasero_burn_session_set_image_output_full:
  * @session: a #BraseroBurnSession
@@ -1506,12 +1563,18 @@ brasero_burn_session_tag_remove (BraseroBurnSession *self,
 	BraseroBurnSessionPrivate *priv;
 
 	g_return_val_if_fail (BRASERO_IS_BURN_SESSION (self), BRASERO_BURN_ERR);
+	g_return_val_if_fail (tag != NULL, BRASERO_BURN_ERR);
 
 	priv = BRASERO_BURN_SESSION_PRIVATE (self);
 	if (!priv->tags)
 		return BRASERO_BURN_ERR;
 
 	g_hash_table_remove (priv->tags, tag);
+
+	g_signal_emit (self,
+	               brasero_burn_session_signals [TAG_CHANGED_SIGNAL],
+	               0,
+	               tag);
 	return BRASERO_BURN_OK;
 }
 
@@ -1524,6 +1587,7 @@ brasero_burn_session_tag_remove (BraseroBurnSession *self,
  * Associates a new @tag with @session. This can be used
  * to pass arbitrary information for plugins, like parameters
  * for video discs, ...
+ * NOTE: the #BraseroBurnSession object takes ownership of @value.
  * See brasero-tags.h for a list of knowns tags.
  *
  * Return value: a #BraseroBurnResult.
@@ -1539,6 +1603,7 @@ brasero_burn_session_tag_add (BraseroBurnSession *self,
 	BraseroBurnSessionPrivate *priv;
 
 	g_return_val_if_fail (BRASERO_IS_BURN_SESSION (self), BRASERO_BURN_ERR);
+	g_return_val_if_fail (tag != NULL, BRASERO_BURN_ERR);
 
 	priv = BRASERO_BURN_SESSION_PRIVATE (self);
 	if (!priv->tags)
@@ -1547,9 +1612,47 @@ brasero_burn_session_tag_add (BraseroBurnSession *self,
 						    g_free,
 						    brasero_burn_session_tag_value_free);
 	g_hash_table_insert (priv->tags, g_strdup (tag), value);
+	g_signal_emit (self,
+	               brasero_burn_session_signals [TAG_CHANGED_SIGNAL],
+	               0,
+	               tag);
+
 	return BRASERO_BURN_OK;
 }
 
+/**
+ * brasero_burn_session_tag_add_int:
+ * @session: a #BraseroBurnSession
+ * @tag: a #gchar *
+ * @value: a #gint
+ *
+ * Associates a new @tag with @session. This can be used
+ * to pass arbitrary information for plugins, like parameters
+ * for video discs, ...
+ * See brasero-tags.h for a list of knowns tags.
+ *
+ * Return value: a #BraseroBurnResult.
+ * BRASERO_BURN_OK if it was successful,
+ * BRASERO_BURN_ERR otherwise.
+ **/
+
+BraseroBurnResult
+brasero_burn_session_tag_add_int (BraseroBurnSession *self,
+                                  const gchar *tag,
+                                  gint value)
+{
+	GValue *gvalue;
+
+	g_return_val_if_fail (BRASERO_IS_BURN_SESSION (self), BRASERO_BURN_ERR);
+	g_return_val_if_fail (tag != NULL, BRASERO_BURN_ERR);
+
+	gvalue = g_new0 (GValue, 1);
+	g_value_init (gvalue, G_TYPE_INT);
+	g_value_set_int (gvalue, value);
+
+	return brasero_burn_session_tag_add (self, tag, gvalue);
+}
+
 /**
  * brasero_burn_session_tag_lookup:
  * @session: a #BraseroBurnSession
@@ -1574,6 +1677,7 @@ brasero_burn_session_tag_lookup (BraseroBurnSession *self,
 	gpointer data;
 
 	g_return_val_if_fail (BRASERO_IS_BURN_SESSION (self), BRASERO_BURN_ERR);
+	g_return_val_if_fail (tag != NULL, BRASERO_BURN_ERR);
 
 	priv = BRASERO_BURN_SESSION_PRIVATE (self);
 	if (!value)
@@ -1586,10 +1690,37 @@ brasero_burn_session_tag_lookup (BraseroBurnSession *self,
 	if (!data)
 		return BRASERO_BURN_ERR;
 
-	*value = data;
+	/* value can be NULL if the function was just called
+	 * to check whether a tag was set. */
+	if (value)
+		*value = data;
 	return BRASERO_BURN_OK;
 }
 
+/**
+ * brasero_burn_session_tag_lookup_int:
+ * @session: a #BraseroBurnSession
+ * @tag: a #gchar
+ *
+ * Retrieves an int value associated with @session through
+ * brasero_session_tag_add () and returns it.
+ *
+ * Return value: a #gint.
+ **/
+
+gint
+brasero_burn_session_tag_lookup_int (BraseroBurnSession *self,
+                                     const gchar *tag)
+{
+	GValue *value = NULL;
+
+	brasero_burn_session_tag_lookup (self, tag, &value);
+	if (!value || !G_VALUE_HOLDS_INT (value))
+		return 0;
+
+	return g_value_get_int (value);
+}
+
 /**
  * Used to save and restore settings/sources
  */
@@ -1759,6 +1890,47 @@ brasero_burn_session_get_dest_media (BraseroBurnSession *self)
 	return brasero_medium_get_status (medium);
 }
 
+/**
+ * brasero_burn_session_get_available_medium_space:
+ * @session: a #BraseroBurnSession
+ *
+ * Returns the maximum space available for the
+ * medium currently inserted in the #BraseroDrive
+ * set as burner with brasero_burn_session_set_burner ().
+ * This takes into account flags.
+ *
+ * Return value: a #goffset.
+ **/
+
+goffset
+brasero_burn_session_get_available_medium_space (BraseroBurnSession *session)
+{
+	BraseroDrive *burner;
+	BraseroBurnFlag flags;
+	BraseroMedium *medium;
+	goffset available_blocks = 0;
+
+	/* Retrieve the size available for burning */
+	burner = brasero_burn_session_get_burner (session);
+	if (!burner)
+		return 0;
+
+	medium = brasero_drive_get_medium (burner);
+	if (!medium)
+		return 0;
+
+	flags = brasero_burn_session_get_flags (session);
+	if (flags & (BRASERO_BURN_FLAG_MERGE|BRASERO_BURN_FLAG_APPEND))
+		brasero_medium_get_free_space (medium, NULL, &available_blocks);
+	else if (brasero_burn_session_can_blank (session) == BRASERO_BURN_OK)
+		brasero_medium_get_capacity (medium, NULL, &available_blocks);
+	else
+		brasero_medium_get_free_space (medium, NULL, &available_blocks);
+
+	BRASERO_BURN_LOG ("Available space on medium %" G_GINT64_FORMAT, available_blocks);
+	return available_blocks;
+}
+
 BraseroMedium *
 brasero_burn_session_get_src_medium (BraseroBurnSession *self)
 {
@@ -1973,6 +2145,42 @@ brasero_burn_session_start (BraseroBurnSession *self)
 	BRASERO_BURN_LOG_TYPE (type, "Input\t=");
 	BRASERO_BURN_LOG_FLAGS (priv->settings->flags, "flags\t=");
 
+	/* also try all known tags */
+	if (brasero_track_type_get_has_stream (type)
+	&&  BRASERO_STREAM_FORMAT_HAS_VIDEO (brasero_track_type_get_stream_format (type))) {
+		GValue *value;
+
+		BRASERO_BURN_LOG ("Tags set:");
+
+		value = NULL;
+		brasero_burn_session_tag_lookup (self,
+						 BRASERO_DVD_STREAM_FORMAT,
+						 &value);
+		if (value)
+			BRASERO_BURN_LOG ("Stream format %i", g_value_get_int (value));
+
+		value = NULL;
+		brasero_burn_session_tag_lookup (self,
+						 BRASERO_VCD_TYPE,
+						 &value);
+		if (value)
+			BRASERO_BURN_LOG ("(S)VCD type %i", g_value_get_int (value));
+
+		value = NULL;
+		brasero_burn_session_tag_lookup (self,
+						 BRASERO_VIDEO_OUTPUT_FRAMERATE,
+						 &value);
+		if (value)
+			BRASERO_BURN_LOG ("Framerate %i", g_value_get_int (value));
+
+		value = NULL;
+		brasero_burn_session_tag_lookup (self,
+						 BRASERO_VIDEO_OUTPUT_ASPECT,
+						 &value);
+		if (value)
+			BRASERO_BURN_LOG ("Aspect %i", g_value_get_int (value));
+	}
+
 	if (!brasero_burn_session_is_dest_file (self)) {
 		BraseroMedium *medium;
 
@@ -2177,7 +2385,6 @@ brasero_burn_session_class_init (BraseroBurnSessionClass *klass)
 	klass->get_output_format = brasero_burn_session_get_output_format_real;
 	klass->set_output_image = brasero_burn_session_set_output_image_real;
 
-	/* This is to delay the setting of track source until we know all settings */
 	/**
  	* BraseroBurnSession::output-changed:
  	* @session: the object which received the signal
@@ -2197,6 +2404,7 @@ brasero_burn_session_class_init (BraseroBurnSessionClass *klass)
 			  G_TYPE_NONE,
 			  1,
 			  BRASERO_TYPE_MEDIUM);
+
 	/**
  	* BraseroBurnSession::track-added:
  	* @session: the object which received the signal
@@ -2216,6 +2424,7 @@ brasero_burn_session_class_init (BraseroBurnSessionClass *klass)
 			  G_TYPE_NONE,
 			  1,
 			  BRASERO_TYPE_TRACK);
+
 	/**
  	* BraseroBurnSession::track-removed:
  	* @session: the object which received the signal
@@ -2237,6 +2446,7 @@ brasero_burn_session_class_init (BraseroBurnSessionClass *klass)
 			  2,
 			  BRASERO_TYPE_TRACK,
 			  G_TYPE_UINT);
+
 	/**
  	* BraseroBurnSession::track-changed:
  	* @session: the object which received the signal
@@ -2256,6 +2466,7 @@ brasero_burn_session_class_init (BraseroBurnSessionClass *klass)
 			  G_TYPE_NONE,
 			  1,
 			  BRASERO_TYPE_TRACK);
+
 	/**
  	* BraseroBurnSession::flags-changed:
  	* @session: the object which received the signal
@@ -2273,6 +2484,26 @@ brasero_burn_session_class_init (BraseroBurnSessionClass *klass)
 			  g_cclosure_marshal_VOID__VOID,
 			  G_TYPE_NONE,
 			  0);
+
+	/**
+ 	* BraseroBurnSession::tag-changed:
+ 	* @session: the object which received the signal
+	*
+ 	* This signal gets emitted when a tag changed for @session (whether it
+	* was removed, added, or it changed).
+ 	*
+ 	*/
+	brasero_burn_session_signals [TAG_CHANGED_SIGNAL] =
+	    g_signal_new ("tag_changed",
+			  BRASERO_TYPE_BURN_SESSION,
+			  G_SIGNAL_RUN_FIRST,
+			  0,
+			  NULL,
+			  NULL,
+			  g_cclosure_marshal_VOID__STRING,
+			  G_TYPE_NONE,
+			  1,
+	                  G_TYPE_STRING);
 }
 
 /**
