@@ -234,11 +234,13 @@ brasero_drive_eject (BraseroDrive *drive,
 
 	BRASERO_MEDIA_LOG ("Trying to eject volume");
 	gvolume = brasero_volume_get_gvolume (BRASERO_VOLUME (priv->medium));
-	res = brasero_gio_operation_eject_volume (gvolume,
-						  priv->cancel,
-						  wait,
-						  error);
-	g_object_unref (gvolume);
+	if (gvolume) {
+		res = brasero_gio_operation_eject_volume (gvolume,
+							  priv->cancel,
+							  wait,
+							  error);
+		g_object_unref (gvolume);
+	}
 
 	return res;
 }
@@ -436,7 +438,7 @@ brasero_drive_unlock (BraseroDrive *drive)
 	g_return_val_if_fail (BRASERO_IS_DRIVE (drive), FALSE);
 
 	priv = BRASERO_DRIVE_PRIVATE (drive);
-	if (!!priv->device)
+	if (!priv->device)
 		return FALSE;
 
 	device = brasero_drive_get_device (drive);
