@@ -65,7 +65,7 @@ const gchar *types [] = {	N_("File"),
 				N_("CDROM"),
 				N_("CD-R"),
 				N_("CD-RW"),
-				N_("DVDROM"),
+				N_("DVD-ROM"),
 				N_("DVD-R"),
 				N_("DVD-RW"),
 				N_("DVD+R"),
@@ -114,6 +114,8 @@ struct _BraseroMediumPrivate
 	guint dummy_sao:1;
 	guint dummy_tao:1;
 	guint burnfree:1;
+	guint sao:1;
+	guint tao:1;
 
 	guint blank_command:1;
 	guint write_command:1;
@@ -829,11 +831,83 @@ brasero_medium_get_capacity (BraseroMedium *medium,
 }
 
 /**
- * Test presence of simulate burning
+ * Test presence of simulate burning/ SAO/ DAO
  */
 
 static gboolean
-brasero_medium_test_simulate_CD_TAO (BraseroMedium *self,
+brasero_medium_set_write_mode_page_tao (BraseroMedium *self,
+                                        BraseroDeviceHandle *handle,
+                                        BraseroScsiErrCode *code)
+{
+	BraseroScsiModeData *data = NULL;
+	BraseroScsiWritePage *wrt_page;
+	BraseroMediumPrivate *priv;
+	BraseroScsiResult result;
+	int size;
+
+	BRASERO_MEDIA_LOG ("Setting write mode page");
+
+	priv = BRASERO_MEDIUM_PRIVATE (self);
+
+	/* NOTE: this works for CDR, DVDR+-, BDR-SRM */
+	/* make sure the current write mode is TAO. Otherwise the drive will
+	 * return the first sector of the pregap instead of the first user
+	 * accessible sector. */
+	result = brasero_spc1_mode_sense_get_page (handle,
+						   BRASERO_SPC_PAGE_WRITE,
+						   &data,
+						   &size,
+						   code);
+	if (result != BRASERO_SCSI_OK) {
+		BRASERO_MEDIA_LOG ("MODE SENSE failed");
+		/* This isn't necessarily a problem! we better try the rest */
+		return FALSE;
+	}
+
+	wrt_page = (BraseroScsiWritePage *) &data->page;
+
+	BRASERO_MEDIA_LOG ("Former write type %d", wrt_page->write_type);
+	BRASERO_MEDIA_LOG ("Former track mode %d", wrt_page->track_mode);
+	BRASERO_MEDIA_LOG ("Former data block type %d", wrt_page->data_block_type);
+
+	/* "reset some stuff to be on the safe side" (words and ideas
+	 * taken from k3b:)). */
+	wrt_page->ps = 0;
+	wrt_page->BUFE = 0;
+	wrt_page->multisession = 0;
+	wrt_page->testwrite = 0;
+	wrt_page->LS_V = 0;
+	wrt_page->copy = 0;
+	wrt_page->FP = 0;
+	wrt_page->session_format = 0;
+	BRASERO_SET_16 (wrt_page->pause_len, 150);
+
+	if (priv->info & BRASERO_MEDIUM_CD) {
+		wrt_page->write_type = BRASERO_SCSI_WRITE_TAO;
+		wrt_page->track_mode = 4;
+	}
+	else if (priv->info & BRASERO_MEDIUM_DVD) {
+		wrt_page->write_type = BRASERO_SCSI_WRITE_PACKET_INC;
+		wrt_page->track_mode = 5;
+	}
+
+	wrt_page->data_block_type = 8;
+
+	result = brasero_spc1_mode_select (handle, data, size, code);
+	g_free (data);
+
+	if (result != BRASERO_SCSI_OK) {
+		BRASERO_MEDIA_LOG ("MODE SELECT failed");
+
+		/* This isn't necessarily a problem! we better try */
+		return FALSE;
+	}
+
+	return TRUE;
+}
+
+static gboolean
+brasero_medium_test_CD_TAO_simulate (BraseroMedium *self,
 				     BraseroDeviceHandle *handle,
 				     BraseroScsiErrCode *code)
 {
@@ -859,8 +933,8 @@ brasero_medium_test_simulate_CD_TAO (BraseroMedium *self,
 	}
 
 	desc = hdr->desc;
-	if (!desc->current)
-		BRASERO_MEDIA_LOG ("Feature is not current");
+	priv->tao = (desc->current != 0);
+	BRASERO_MEDIA_LOG ("TAO feature is %s", priv->tao? "supported":"not supported");
 
 	tao_desc = (BraseroScsiCDTAODesc *) desc->data;
 	priv->dummy_tao = tao_desc->dummy != 0;
@@ -876,7 +950,7 @@ brasero_medium_test_simulate_CD_TAO (BraseroMedium *self,
 }
 
 static gboolean
-brasero_medium_test_simulate_CD_SAO (BraseroMedium *self,
+brasero_medium_test_CD_SAO_simulate (BraseroMedium *self,
 				     BraseroDeviceHandle *handle,
 				     BraseroScsiErrCode *code)
 {
@@ -901,8 +975,8 @@ brasero_medium_test_simulate_CD_SAO (BraseroMedium *self,
 	}
 
 	desc = hdr->desc;
-	if (!desc->current)
-		BRASERO_MEDIA_LOG ("Feature is not current");
+	priv->sao = (desc->current != 0);
+	BRASERO_MEDIA_LOG ("SAO feature is %s", priv->sao? "supported":"not supported");
 
 	sao_desc = (BraseroScsiCDSAODesc *) desc->data;
 	priv->dummy_sao = sao_desc->dummy != 0;
@@ -913,9 +987,9 @@ brasero_medium_test_simulate_CD_SAO (BraseroMedium *self,
 }
 
 static gboolean
-brasero_medium_test_simulate_DVDRW (BraseroMedium *self,
-				    BraseroDeviceHandle *handle,
-				    BraseroScsiErrCode *code)
+brasero_medium_test_DVDRW_incremental_simulate (BraseroMedium *self,
+                                                BraseroDeviceHandle *handle,
+                                                BraseroScsiErrCode *code)
 {
 	BraseroScsiDVDRWlessWrtDesc *less_wrt_desc;
 	BraseroScsiGetConfigHdr *hdr = NULL;
@@ -926,8 +1000,26 @@ brasero_medium_test_simulate_DVDRW (BraseroMedium *self,
 
 	priv = BRASERO_MEDIUM_PRIVATE (self);
 
+	/* Try incremental feature */
+	BRASERO_MEDIA_LOG ("Checking incremental and simulate feature");
+	result = brasero_mmc2_get_configuration_feature (handle,
+							 BRASERO_SCSI_FEAT_WRT_INCREMENT,
+							 &hdr,
+							 &size,
+							 code);
+	if (result != BRASERO_SCSI_OK) {
+		BRASERO_MEDIA_LOG ("GET CONFIGURATION failed");
+		return FALSE;
+	}
+
+	priv->tao = (hdr->desc->current != 0);
+	g_free (hdr);
+	hdr = NULL;
+
+	BRASERO_MEDIA_LOG ("Incremental feature is %s", priv->tao? "supported":"not supported");
+
 	/* Only DVD-R(W) support simulation */
-	BRASERO_MEDIA_LOG ("Checking simulate (DVD-R/W)");
+	BRASERO_MEDIA_LOG ("Checking (DVD-R(W) simulate)");
 	result = brasero_mmc2_get_configuration_feature (handle,
 							 BRASERO_SCSI_FEAT_WRT_DVD_LESS,
 							 &hdr,
@@ -939,8 +1031,11 @@ brasero_medium_test_simulate_DVDRW (BraseroMedium *self,
 	}
 
 	desc = hdr->desc;
-	if (!desc->current)
-		BRASERO_MEDIA_LOG ("Feature is not current");
+
+	/* NOTE: SAO feature is always supported if this feature is current
+	 * See MMC5 5.3.25 Write feature parameters */
+	priv->sao = (desc->current != 0);
+	BRASERO_MEDIA_LOG ("SAO feature is %s", priv->sao? "supported":"not supported");
 
 	less_wrt_desc = (BraseroScsiDVDRWlessWrtDesc *) desc->data;
 	priv->dummy_sao = less_wrt_desc->dummy != 0;
@@ -961,7 +1056,7 @@ brasero_medium_test_simulate_DVDRW (BraseroMedium *self,
  */
 
 static void
-brasero_medium_test_simulate_2A (BraseroMedium *self,
+brasero_medium_test_2A_simulate (BraseroMedium *self,
 				 BraseroDeviceHandle *handle,
 				 BraseroScsiErrCode *code)
 {
@@ -973,6 +1068,7 @@ brasero_medium_test_simulate_2A (BraseroMedium *self,
 
 	priv = BRASERO_MEDIUM_PRIVATE (self);
 
+	/* FIXME: we need to get a way to get the write types */
 	result = brasero_spc1_mode_sense_get_page (handle,
 						   BRASERO_SPC_PAGE_STATUS,
 						   &data,
@@ -1008,18 +1104,18 @@ brasero_medium_init_caps (BraseroMedium *self,
 
 	priv = BRASERO_MEDIUM_PRIVATE (self);
 
-	/* These special media don't support/need burnfree and simulation */
+	/* These special media don't support/need burnfree, simulation, tao/sao */
 	if (priv->info & (BRASERO_MEDIUM_PLUS|BRASERO_MEDIUM_BD))
 		return;
 
 	if (priv->info & BRASERO_MEDIUM_CD) {
 		/* we have to do both */
-		res = brasero_medium_test_simulate_CD_SAO (self, handle, code);
+		res = brasero_medium_test_CD_SAO_simulate (self, handle, code);
 		if (res)
-			brasero_medium_test_simulate_CD_TAO (self, handle, code);
+			brasero_medium_test_CD_TAO_simulate (self, handle, code);
 	}
 	else
-		res = brasero_medium_test_simulate_DVDRW (self, handle, code);
+		res = brasero_medium_test_DVDRW_incremental_simulate (self, handle, code);
 
 	BRASERO_MEDIA_LOG ("Tested simulation %d %d, burnfree %d",
 			  priv->dummy_tao,
@@ -1031,7 +1127,7 @@ brasero_medium_init_caps (BraseroMedium *self,
 
 	/* it didn't work out as expected use fallback */
 	BRASERO_MEDIA_LOG ("Using fallback 2A page for testing simulation and burnfree");
-	brasero_medium_test_simulate_2A (self, handle, code);
+	brasero_medium_test_2A_simulate (self, handle, code);
 
 	BRASERO_MEDIA_LOG ("Re-tested simulation %d %d, burnfree %d",
 			  priv->dummy_tao,
@@ -1124,7 +1220,9 @@ brasero_medium_get_capacity_DVD_RW (BraseroMedium *self,
 	current = hdr->max_caps;
 	if (!(current->type & BRASERO_SCSI_DESC_FORMATTED)) {
 		BRASERO_MEDIA_LOG ("Unformatted media");
-		priv->info |= BRASERO_MEDIUM_UNFORMATTED;
+		/* If it's sequential, it's not unformatted */
+		if (!(priv->info & BRASERO_MEDIUM_SEQUENTIAL))
+			priv->info |= BRASERO_MEDIUM_UNFORMATTED;
 
 		/* if unformatted, a DVD-RAM will return its maximum formattable
 		 * size in this descriptor and that's what we're looking for. */
@@ -1674,7 +1772,7 @@ brasero_medium_track_set_leadout_DVDR_blank (BraseroMedium *self,
 	 * they are blank. */
 	current = hdr->max_caps;
 	if (current->type & BRASERO_SCSI_DESC_FORMATTED) {
-		BRASERO_MEDIA_LOG ("Unformatted medium");
+		BRASERO_MEDIA_LOG ("Formatted medium");
 		g_free (hdr);
 		return FALSE;
 	}
@@ -1733,79 +1831,6 @@ brasero_medium_track_set_leadout_CDR_blank (BraseroMedium *self,
 	return TRUE;
 }
 
-static gboolean
-brasero_medium_set_write_mode_page (BraseroMedium *self,
-				    BraseroDeviceHandle *handle,
-				    BraseroScsiErrCode *code)
-{
-	BraseroScsiModeData *data = NULL;
-	BraseroScsiWritePage *wrt_page;
-	BraseroMediumPrivate *priv;
-	BraseroScsiResult result;
-	int size;
-
-	BRASERO_MEDIA_LOG ("Setting write mode page");
-
-	priv = BRASERO_MEDIUM_PRIVATE (self);
-
-	/* NOTE: this works for CDR, DVDR+-, BDR-SRM */
-	/* make sure the current write mode is TAO. Otherwise the drive will
-	 * return the first sector of the pregap instead of the first user
-	 * accessible sector. */
-	result = brasero_spc1_mode_sense_get_page (handle,
-						   BRASERO_SPC_PAGE_WRITE,
-						   &data,
-						   &size,
-						   code);
-	if (result == BRASERO_SCSI_OK) {
-		wrt_page = (BraseroScsiWritePage *) &data->page;
-
-		BRASERO_MEDIA_LOG ("Former write type %d", wrt_page->write_type);
-		BRASERO_MEDIA_LOG ("Former track mode %d", wrt_page->track_mode);
-		BRASERO_MEDIA_LOG ("Former data block type %d", wrt_page->data_block_type);
-
-		/* "reset some stuff to be on the safe side" (words and ideas
-		 * taken from k3b:)). */
-		wrt_page->ps = 0;
-		wrt_page->BUFE = 0;
-		wrt_page->multisession = 0;
-		wrt_page->testwrite = 0;
-		wrt_page->LS_V = 0;
-		wrt_page->copy = 0;
-		wrt_page->FP = 0;
-		wrt_page->session_format = 0;
-		BRASERO_SET_16 (wrt_page->pause_len, 150);
-
-		if (priv->info & BRASERO_MEDIUM_CD) {
-			wrt_page->write_type = BRASERO_SCSI_WRITE_TAO;
-			wrt_page->track_mode = 4;
-		}
-		else if (priv->info & BRASERO_MEDIUM_DVD) {
-			wrt_page->write_type = BRASERO_SCSI_WRITE_PACKET_INC;
-			wrt_page->track_mode = 5;
-		}
-
-		wrt_page->data_block_type = 8;
-
-		result = brasero_spc1_mode_select (handle, data, size, code);
-		g_free (data);
-
-		if (result != BRASERO_SCSI_OK) {
-			BRASERO_MEDIA_LOG ("MODE SELECT failed");
-
-			/* This isn't necessarily a problem! we better try */
-			return FALSE;
-		}
-	}
-	else {
-		BRASERO_MEDIA_LOG ("MODE SENSE failed");
-		/* This isn't necessarily a problem! we better try the rest */
-		return FALSE;
-	}
-
-	return TRUE;
-}
-
 static gboolean
 brasero_medium_track_set_leadout (BraseroMedium *self,
 				  BraseroDeviceHandle *handle,
@@ -1833,7 +1858,7 @@ brasero_medium_track_set_leadout (BraseroMedium *self,
 		 * Carry on even if it fails.
 		 * This can work with CD-R/W and DVD-R/W. + media don't use the
 		 * write mode page anyway. */
-		result = brasero_medium_set_write_mode_page (self, handle, code);
+		result = brasero_medium_set_write_mode_page_tao (self, handle, code);
 		if (result == FALSE
 		&&  BRASERO_MEDIUM_IS (priv->info, BRASERO_MEDIUM_CDR|BRASERO_MEDIUM_BLANK))
 			return brasero_medium_track_set_leadout_CDR_blank (self,
@@ -2298,7 +2323,6 @@ brasero_medium_get_medium_type (BraseroMedium *self,
 
 		/* If this fails it means that this drive is probably older than
 		 * MMC1 spec or does not conform to it. */
-		if (result != TRUE)
 		if (result != TRUE)
 			return FALSE;
 
@@ -2830,7 +2854,6 @@ brasero_medium_init_real (BraseroMedium *object,
 		return;
 
 	result = brasero_medium_get_medium_type (object, handle, &code);
-	if (result != TRUE)
 	if (result != TRUE)
 		return;
 
@@ -2838,7 +2861,6 @@ brasero_medium_init_real (BraseroMedium *object,
 		return;
 
 	result = brasero_medium_get_speed (object, handle, &code);
-	if (result != TRUE)
 	if (result != TRUE)
 		return;
 
@@ -2849,6 +2871,10 @@ brasero_medium_init_real (BraseroMedium *object,
 	if (priv->probe_cancelled)
 		return;
 
+	brasero_medium_init_caps (object, handle, &code);
+	if (priv->probe_cancelled)
+		return;
+
 	result = brasero_medium_get_contents (object, handle, &code);
 	if (result != TRUE)
 	if (result != TRUE)
@@ -2865,10 +2891,6 @@ brasero_medium_init_real (BraseroMedium *object,
 	if (priv->probe_cancelled)
 		return;
 
-	brasero_medium_init_caps (object, handle, &code);
-	if (priv->probe_cancelled)
-		return;
-
 	/* read CD-TEXT title */
 	if (priv->info & BRASERO_MEDIUM_HAS_AUDIO)
 		brasero_medium_read_CD_TEXT (object, handle, &code);
@@ -2905,8 +2927,10 @@ brasero_medium_probed (gpointer data)
 
 	priv = BRASERO_MEDIUM_PRIVATE (data);
 
-	g_thread_join (priv->probe);
-	priv->probe = NULL;
+	if (priv->probe) {
+		g_thread_join (priv->probe);
+		priv->probe = NULL;
+	}
 
 	/* This signal must be emitted in the main thread */
 	GDK_THREADS_ENTER ();
@@ -2934,7 +2958,7 @@ brasero_medium_probe_thread (gpointer self)
 
 	/* the drive might be busy (a burning is going on) so we don't block
 	 * but we re-try to open it every second */
-	device = brasero_drive_get_block_device (priv->drive);
+	device = brasero_drive_get_device (priv->drive);
 	BRASERO_MEDIA_LOG ("Trying to open device %s", device);
 
 	handle = brasero_device_handle_open (device, FALSE, &code);
@@ -2960,8 +2984,15 @@ brasero_medium_probe_thread (gpointer self)
 
 		/* NOTE: if we wanted to know the status we'd need to read the 
 		 * error code variable which is currently NULL */
-		while (brasero_spc1_test_unit_ready (handle, NULL) != BRASERO_SCSI_OK) {
-			sleep (1);
+		while (brasero_spc1_test_unit_ready (handle, &code) != BRASERO_SCSI_OK) {
+			if (code != BRASERO_SCSI_NOT_READY) {
+				priv->probe = NULL;
+				brasero_device_handle_close (handle);
+				BRASERO_MEDIA_LOG ("Device does not respond");
+				break;
+			}
+
+			sleep (2);
 
 			if (priv->probe_cancelled) {
 				priv->probe = NULL;
@@ -3033,9 +3064,13 @@ brasero_medium_finalize (GObject *object)
 	BRASERO_MEDIA_LOG ("Finalizing Medium object");
 
 	if (priv->probe) {
+		GThread *probe;
+
+		probe = priv->probe;
 		priv->probe_cancelled = TRUE;
-		g_thread_join (priv->probe);
-		priv->probe = 0;
+
+		g_thread_join (probe);
+		priv->probe = NULL;
 	}
 
 	if (priv->probe_id) {
@@ -3225,6 +3260,45 @@ brasero_medium_can_be_rewritten (BraseroMedium *medium)
 
 	return FALSE;
 }
+/**
+ * brasero_medium_can_use_sao:
+ * @medium: #BraseroMedium
+ *
+ * Gets whether the medium supports SAO.
+ *
+ * Return value: a #gboolean. TRUE if the medium can use SAO write mode , FALSE otherwise.
+ *
+ **/
+gboolean
+brasero_medium_can_use_sao (BraseroMedium *medium)
+{
+	BraseroMediumPrivate *priv;
+
+	g_return_val_if_fail (BRASERO_IS_MEDIUM (medium), FALSE);
+
+	priv = BRASERO_MEDIUM_PRIVATE (medium);
+	return priv->sao;
+}
+
+/**
+ * brasero_medium_can_use_tao:
+ * @medium: #BraseroMedium
+ *
+ * Gets whether the medium supports TAO.
+ *
+ * Return value: a #gboolean. TRUE if the medium can use TAO write mode, FALSE otherwise.
+ *
+ **/
+gboolean
+brasero_medium_can_use_tao (BraseroMedium *medium)
+{
+	BraseroMediumPrivate *priv;
+
+	g_return_val_if_fail (BRASERO_IS_MEDIUM (medium), FALSE);
+
+	priv = BRASERO_MEDIUM_PRIVATE (medium);
+	return priv->tao;
+}
 
 /**
  * brasero_medium_can_use_dummy_for_sao:
