@@ -260,13 +260,11 @@ brasero_cdrdao_set_argv_device (BraseroCdrdao *cdrdao,
 
 	g_ptr_array_add (argv, g_strdup ("--device"));
 
-#ifdef HAVE_CAM_LIB_H
-	/* FreeBSD like that better */
+	/* NOTE: that function returns either bus_target_lun or the device path
+	 * according to OSes. Basically it returns bus/target/lun only for FreeBSD
+	 * which is the only OS in need for that. For all others it returns the device
+	 * path. */
 	brasero_job_get_bus_target_lun (BRASERO_JOB (cdrdao), &device);
-#else
-	brasero_job_get_device (BRASERO_JOB (cdrdao), &device);
-#endif
-
 	g_ptr_array_add (argv, device);
 }
 
@@ -346,7 +344,11 @@ brasero_cdrdao_set_argv_record (BraseroCdrdao *cdrdao,
 		brasero_job_get_current_track (BRASERO_JOB (cdrdao), &track);
 		drive = brasero_track_disc_get_drive (BRASERO_TRACK_DISC (track));
 
-		g_ptr_array_add (argv, g_strdup (brasero_drive_get_device (drive)));
+		/* NOTE: that function returns either bus_target_lun or the device path
+		 * according to OSes. Basically it returns bus/target/lun only for FreeBSD
+		 * which is the only OS in need for that. For all others it returns the device
+		 * path. */
+		g_ptr_array_add (argv, brasero_drive_get_bus_target_lun_string (drive));
 	}
 	else if (brasero_track_type_get_has_image (type)) {
 		gchar *cuepath;
@@ -442,7 +444,11 @@ brasero_cdrdao_set_argv_image (BraseroCdrdao *cdrdao,
 	brasero_job_get_current_track (BRASERO_JOB (cdrdao), &track);
 	drive = brasero_track_disc_get_drive (BRASERO_TRACK_DISC (track));
 
-	g_ptr_array_add (argv, g_strdup (brasero_drive_get_device (drive)));
+	/* NOTE: that function returns either bus_target_lun or the device path
+	 * according to OSes. Basically it returns bus/target/lun only for FreeBSD
+	 * which is the only OS in need for that. For all others it returns the device
+	 * path. */
+	g_ptr_array_add (argv, brasero_drive_get_bus_target_lun_string (drive));
 	g_ptr_array_add (argv, g_strdup ("--read-raw"));
 
 	/* This is done so that if a cue file is required we first generate
