@@ -34,8 +34,7 @@
 #include <glib.h>
 #include <glib-object.h>
 
-#include <gtk/gtkuimanager.h>
-#include <gtk/gtkhpaned.h>
+#include <gtk/gtk.h>
 
 G_BEGIN_DECLS
 
@@ -79,7 +78,6 @@ brasero_layout_add_source (BraseroLayout *layout,
 			   GtkWidget *child,
 			   const gchar *id,
 			   const gchar *subtitle,
-			   const gchar *tooltip,
 			   const gchar *icon_name,
 			   BraseroLayoutType types);
 void
