@@ -402,8 +402,9 @@ _get_tracks (xmlDocPtr project,
 	for (iter = tracks; iter; iter = iter->next) {
 		BraseroTrack *newtrack;
 
-		newtrack = tracks->data;
+		newtrack = iter->data;
 		brasero_burn_session_add_track (session, newtrack, NULL);
+		g_object_unref (newtrack);
 	}
 
 	g_slist_free (tracks);
@@ -717,14 +718,17 @@ _save_data_track_xml (xmlTextWriter *project,
 	GSList *iter;
 	GSList *tracks;
 	GSList *grafts;
+	gchar *filename;
 	BraseroTrackDataCfg *track;
 
 	tracks = brasero_burn_session_get_tracks (session);
 	track = BRASERO_TRACK_DATA_CFG (tracks->data);
 
-	if (brasero_track_data_cfg_get_icon_path (track)) {
+	filename = brasero_track_data_cfg_get_icon_path (track);
+	if (filename) {
 		/* Write the icon if any */
-		success = xmlTextWriterWriteElement (project, (xmlChar *) "icon", (xmlChar *) brasero_track_data_cfg_get_icon_path (track));
+		success = xmlTextWriterWriteElement (project, (xmlChar *) "icon", (xmlChar *) filename);
+		g_free (filename);
 		if (success < 0)
 			return FALSE;
 	}
