@@ -29,11 +29,17 @@
 
 #include <gtk/gtk.h>
 
+#include "brasero-misc.h"
+#include "brasero-metadata.h"
+
+#include "brasero-units.h"
+
+#include "brasero-track.h"
+#include "brasero-track-stream.h"
+
 #include "brasero-split-dialog.h"
 #include "brasero-player.h"
 #include "brasero-utils.h"
-#include "brasero-metadata.h"
-#include "burn-track.h"
 
 enum {
 	START_COL,
@@ -102,7 +108,7 @@ brasero_split_dialog_set_boundaries (BraseroSplitDialog *self,
 	if (BRASERO_DURATION_TO_BYTES (end) % 2352)
 		end += BRASERO_BYTES_TO_DURATION (2352 - (BRASERO_DURATION_TO_BYTES (end) % 2352));
 
-	if (end - start < BRASERO_MIN_AUDIO_TRACK_LENGTH)
+	if (end - start < BRASERO_MIN_STREAM_LENGTH)
 		return;
 
 	priv->start = start;
@@ -211,18 +217,18 @@ brasero_split_dialog_cut (BraseroSplitDialog *self,
 
 		/* check that pos > 300 sectors ( == 4 sec ) */
 		if (warn
-		&&  pos - priv->start < BRASERO_MIN_AUDIO_TRACK_LENGTH
+		&&  pos - priv->start < BRASERO_MIN_STREAM_LENGTH
 		&& !brasero_split_dialog_size_error (self))
 			return FALSE;
 
 		if (warn
-		&&  end - (pos + 1) < BRASERO_MIN_AUDIO_TRACK_LENGTH
+		&&  end - (pos + 1) < BRASERO_MIN_STREAM_LENGTH
 		&& !brasero_split_dialog_size_error (self))
 			return FALSE;
 
-		length_str = brasero_utils_get_time_string (pos - priv->start, TRUE, FALSE);
-		start_str = brasero_utils_get_time_string (priv->start, TRUE, FALSE);
-		end_str = brasero_utils_get_time_string (pos, TRUE, FALSE);
+		length_str = brasero_units_get_time_string (pos - priv->start, TRUE, FALSE);
+		start_str = brasero_units_get_time_string (priv->start, TRUE, FALSE);
+		end_str = brasero_units_get_time_string (pos, TRUE, FALSE);
 
 		gtk_list_store_append (priv->model, &iter);
 		gtk_list_store_set (priv->model, &iter,
@@ -238,9 +244,9 @@ brasero_split_dialog_cut (BraseroSplitDialog *self,
 		g_free (end_str);
 
 		pos ++;
-		length_str = brasero_utils_get_time_string (end - pos, TRUE, FALSE);
-		start_str = brasero_utils_get_time_string (pos, TRUE, FALSE);
-		end_str = brasero_utils_get_time_string (end, TRUE, FALSE);
+		length_str = brasero_units_get_time_string (end - pos, TRUE, FALSE);
+		start_str = brasero_units_get_time_string (pos, TRUE, FALSE);
+		end_str = brasero_units_get_time_string (end, TRUE, FALSE);
 		
 		gtk_list_store_append (priv->model, &iter);
 		gtk_list_store_set (priv->model, &iter,
@@ -273,12 +279,12 @@ brasero_split_dialog_cut (BraseroSplitDialog *self,
 
 		/* check the size of the new tracks */
 		if (warn
-		&& (pos - start) < BRASERO_MIN_AUDIO_TRACK_LENGTH
+		&& (pos - start) < BRASERO_MIN_STREAM_LENGTH
 		&& !brasero_split_dialog_size_error (self))
 			return FALSE;
 
 		if (warn
-		&& (end - (pos + 1)) < BRASERO_MIN_AUDIO_TRACK_LENGTH
+		&& (end - (pos + 1)) < BRASERO_MIN_STREAM_LENGTH
 		&& !brasero_split_dialog_size_error (self))
 			return FALSE;
 
@@ -320,14 +326,14 @@ brasero_split_dialog_cut (BraseroSplitDialog *self,
 
 		/* check the size of the new slice */
 		if (warn
-		&& (slice.end - slice.start) < BRASERO_MIN_AUDIO_TRACK_LENGTH
+		&& (slice.end - slice.start) < BRASERO_MIN_STREAM_LENGTH
 		&& !brasero_split_dialog_size_error (self))
 			return FALSE;
 	}
 	else {
 		/* we are in the middle of an existing slice */
-		length_str = brasero_utils_get_time_string (pos - slice.start, TRUE, FALSE);
-		end_str = brasero_utils_get_time_string (pos, TRUE, FALSE);
+		length_str = brasero_units_get_time_string (pos - slice.start, TRUE, FALSE);
+		end_str = brasero_units_get_time_string (pos, TRUE, FALSE);
 
 		gtk_tree_model_sort_convert_iter_to_child_iter (GTK_TREE_MODEL_SORT (model),
 								&child,
@@ -349,9 +355,9 @@ brasero_split_dialog_cut (BraseroSplitDialog *self,
 	/* create a new one */
 	gtk_list_store_append (priv->model, &child);
 
-	length_str = brasero_utils_get_time_string (slice.end - pos, TRUE, FALSE);
-	start_str = brasero_utils_get_time_string (pos, TRUE, FALSE);
-	end_str = brasero_utils_get_time_string (slice.end, TRUE, FALSE);
+	length_str = brasero_units_get_time_string (slice.end - pos, TRUE, FALSE);
+	start_str = brasero_units_get_time_string (pos, TRUE, FALSE);
+	end_str = brasero_units_get_time_string (slice.end, TRUE, FALSE);
 
 	gtk_list_store_set (priv->model, &child,
 			    START_COL, pos,
@@ -400,21 +406,21 @@ brasero_split_dialog_remove_range (BraseroSplitDialog *self,
 		 * - 0 => start 
 		 * - end => song end
 		 * also make sure that the track is longer than 4 sec */
-		if (start - priv->start < BRASERO_MIN_AUDIO_TRACK_LENGTH
+		if (start - priv->start < BRASERO_MIN_STREAM_LENGTH
 		&& !brasero_split_dialog_size_error (self)) {
 			/* that's not necessarily a good solution */
-			start = BRASERO_MIN_AUDIO_TRACK_LENGTH;
+			start = BRASERO_MIN_STREAM_LENGTH;
 			if (start > end)
 				end = start;
 		}
 
-		if ((length - end) < BRASERO_MIN_AUDIO_TRACK_LENGTH
+		if ((length - end) < BRASERO_MIN_STREAM_LENGTH
 		&& !brasero_split_dialog_size_error (self))
-			end = length - BRASERO_MIN_AUDIO_TRACK_LENGTH;
+			end = length - BRASERO_MIN_STREAM_LENGTH;
 
-		length_str = brasero_utils_get_time_string (start - priv->start, TRUE, FALSE);
-		start_str = brasero_utils_get_time_string (priv->start, TRUE, FALSE);
-		end_str = brasero_utils_get_time_string (start, TRUE, FALSE);
+		length_str = brasero_units_get_time_string (start - priv->start, TRUE, FALSE);
+		start_str = brasero_units_get_time_string (priv->start, TRUE, FALSE);
+		end_str = brasero_units_get_time_string (start, TRUE, FALSE);
 
 		gtk_list_store_append (priv->model, &iter);
 		gtk_list_store_set (priv->model, &iter,
@@ -432,9 +438,9 @@ brasero_split_dialog_remove_range (BraseroSplitDialog *self,
 		if (end == length)
 			return;
 
-		length_str = brasero_utils_get_time_string (length - end, TRUE, FALSE);
-		start_str = brasero_utils_get_time_string (end, TRUE, FALSE);
-		end_str = brasero_utils_get_time_string (length, TRUE, FALSE);
+		length_str = brasero_units_get_time_string (length - end, TRUE, FALSE);
+		start_str = brasero_units_get_time_string (end, TRUE, FALSE);
+		end_str = brasero_units_get_time_string (length, TRUE, FALSE);
 		
 		gtk_list_store_append (priv->model, &iter);
 		gtk_list_store_set (priv->model, &iter,
@@ -478,12 +484,12 @@ brasero_split_dialog_remove_range (BraseroSplitDialog *self,
 			if (end < track_end) {
 				/* reduce the size but make sure the remaining 
 				 * track is > 4 sec */
-				if ((track_end - end) < BRASERO_MIN_AUDIO_TRACK_LENGTH
+				if ((track_end - end) < BRASERO_MIN_STREAM_LENGTH
 				&& !brasero_split_dialog_size_error (self))
-					end = track_end - BRASERO_MIN_AUDIO_TRACK_LENGTH;
+					end = track_end - BRASERO_MIN_STREAM_LENGTH;
 
-				start_str = brasero_utils_get_time_string (end, TRUE, FALSE);
-				length_str = brasero_utils_get_time_string (track_end - end, TRUE, FALSE);
+				start_str = brasero_units_get_time_string (end, TRUE, FALSE);
+				length_str = brasero_units_get_time_string (track_end - end, TRUE, FALSE);
 				gtk_list_store_set (priv->model, &child,
 						    START_COL, end,
 						    START_STR_COL, start_str,
@@ -502,12 +508,12 @@ brasero_split_dialog_remove_range (BraseroSplitDialog *self,
 
 			/* reduce the size but make sure the remaining track is
 			 * > 4 sec else change it */
-			if ((start - track_start) < BRASERO_MIN_AUDIO_TRACK_LENGTH
+			if ((start - track_start) < BRASERO_MIN_STREAM_LENGTH
 			&& !brasero_split_dialog_size_error (self))
-				start = track_start + BRASERO_MIN_AUDIO_TRACK_LENGTH;
+				start = track_start + BRASERO_MIN_STREAM_LENGTH;
 
-			start_str = brasero_utils_get_time_string (start, TRUE, FALSE);
-			length_str = brasero_utils_get_time_string (start - track_start, TRUE, FALSE);
+			start_str = brasero_units_get_time_string (start, TRUE, FALSE);
+			length_str = brasero_units_get_time_string (start - track_start, TRUE, FALSE);
 			gtk_list_store_set (priv->model, &child,
 					    END_COL, start,
 					    END_STR_COL, start_str,
@@ -528,15 +534,15 @@ brasero_split_dialog_remove_range (BraseroSplitDialog *self,
 
 			/* create a new track with the remaining time.
 			 * make sure the remaining track is > 4 sec */
-			if ((track_end - end) < BRASERO_MIN_AUDIO_TRACK_LENGTH
+			if ((track_end - end) < BRASERO_MIN_STREAM_LENGTH
 			&& !brasero_split_dialog_size_error (self))
-				end = track_end - BRASERO_MIN_AUDIO_TRACK_LENGTH;
+				end = track_end - BRASERO_MIN_STREAM_LENGTH;
 
 			gtk_list_store_append (priv->model, &child);
 
-			length_str = brasero_utils_get_time_string (track_end - end, TRUE, FALSE);
-			start_str = brasero_utils_get_time_string (end, TRUE, FALSE);
-			end_str = brasero_utils_get_time_string (track_end, TRUE, FALSE);
+			length_str = brasero_units_get_time_string (track_end - end, TRUE, FALSE);
+			start_str = brasero_units_get_time_string (end, TRUE, FALSE);
+			end_str = brasero_units_get_time_string (track_end, TRUE, FALSE);
 
 			gtk_list_store_set (priv->model, &child,
 					    START_COL, end,
@@ -565,12 +571,12 @@ brasero_split_dialog_remove_range (BraseroSplitDialog *self,
 			}
 
 			/* resize (make sure about the 4s) */
-			if ((track_end - end) < BRASERO_MIN_AUDIO_TRACK_LENGTH
+			if ((track_end - end) < BRASERO_MIN_STREAM_LENGTH
 			&& !brasero_split_dialog_size_error (self))
-				end = track_end - BRASERO_MIN_AUDIO_TRACK_LENGTH;
+				end = track_end - BRASERO_MIN_STREAM_LENGTH;
 
-			start_str = brasero_utils_get_time_string (end, TRUE, FALSE);
-			length_str = brasero_utils_get_time_string (track_end - end, TRUE, FALSE);
+			start_str = brasero_units_get_time_string (end, TRUE, FALSE);
+			length_str = brasero_units_get_time_string (track_end - end, TRUE, FALSE);
 			gtk_list_store_set (priv->model, &child,
 					    START_COL, end,
 					    START_STR_COL, start_str,
@@ -747,7 +753,7 @@ brasero_split_dialog_cut_clicked_cb (GtkButton *button,
 		sec = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (priv->spin_sec));
 
 		sec *= 1000000000;
-		if (sec < BRASERO_MIN_AUDIO_TRACK_LENGTH
+		if (sec < BRASERO_MIN_STREAM_LENGTH
 		&& !brasero_split_dialog_size_error (self))
 			return;
 
@@ -771,12 +777,14 @@ brasero_split_dialog_cut_clicked_cb (GtkButton *button,
 		length = priv->end - priv->start;
 		step = length / parts;
 
-		if (step < BRASERO_MIN_AUDIO_TRACK_LENGTH
+		if (step < BRASERO_MIN_STREAM_LENGTH
 		&& !brasero_split_dialog_size_error (self))
 			return;
 
 		gtk_list_store_clear (priv->model);
-		for (start = step; start < length; start += step)
+
+		parts --;
+		for (start = step; start < length && parts; start += step, parts --)
 			brasero_split_dialog_cut (self, start, FALSE);
 
 		return;
@@ -860,9 +868,9 @@ brasero_split_dialog_merge_clicked_cb (GtkButton *button,
 
 		} while (gtk_tree_selection_iter_is_selected (selection, &next));
 
-		length_str = brasero_utils_get_time_string (end - start, TRUE, FALSE);
-		start_str = brasero_utils_get_time_string (start, TRUE, FALSE);
-		end_str = brasero_utils_get_time_string (end, TRUE, FALSE);
+		length_str = brasero_units_get_time_string (end - start, TRUE, FALSE);
+		start_str = brasero_units_get_time_string (start, TRUE, FALSE);
+		end_str = brasero_units_get_time_string (end, TRUE, FALSE);
 
 		gtk_list_store_set (priv->model, &child,
 				    START_COL, (gint64) start,
